#include "evidence.h"

#include <iostream>
#include <sstream>
#include <cstdio>

#include <QLineEdit>
#include <QHeaderView>
#include <QMenuBar>
#include <QWidget>
#include <QPalette>
#include <QWebEngineView>

using namespace std;

Evidence::Evidence(QWidget *parent)
    : QMainWindow(parent)
{
    mapUrl = new char[256];
    sprintf(mapUrl, "%s", "http://homel.vsb.cz/~hol716/map.php?q=%s&zoom=%s");

    createMenu();

    layout = new QVBoxLayout();

    table = new QTableView();
    table->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    table->setEditTriggers(QTableView::NoEditTriggers);

    fillTable(table);
    connect(table, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(personSelected(QModelIndex)));

    layout->addWidget(table);

    // QFormLayout na Jmeno, Prijmeni, Vek

    tab = new QTabWidget();
    tab->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
    layout->addWidget(tab);

    tab1 = new QFrame();
    tab1_l = new QGridLayout();
    tab1_l->addWidget(new QLabel(QString("Adresa")), 0, 0);
    tab1_l->setSizeConstraint(QLayout::SetFixedSize);
    tab1->setLayout(tab1_l);
    tab->addTab(tab1, QString("Adresa"));

    // Tlacitka: Novy, Ulozit, Smazat

    main_frame = new QFrame();
    main_frame->setLayout(layout);
    setCentralWidget(main_frame);
}

void Evidence::createMenu()
{
    filemenu = new QMenu("&Soubor");
    exit_act = new QAction("&Konec", this);
    filemenu->addAction(exit_act);

    connect(exit_act, SIGNAL(triggered()), this, SLOT(close()));

    menuBar()->addMenu(filemenu);
}

void Evidence::fillTable(QTableView* table)
{
    int nrow = 4;
    int ncol = 4;

    const char* cols[] = { "Jmeno", "Prijmeni", "Vek", "Adresa" };
    const char* names[] = { "Karel", "Vaclav", "Pavel", "Petr" };
    const char* snames[] = { "Gott", "Sverkos", "Nedved", "Nedved" };
    const char* ages[] = { "75", "30", "35", "42" };
    const char* addresses[] = { "17. listopadu 15, Ostrava,Česká republika", "17. listopadu 15, Ostrava,Česká republika", "17. listopadu 15, Ostrava,Česká republika", "17. listopadu 15, Ostrava,Česká republika" };

    model = new QStandardItemModel( nrow, ncol, this );

    for (int r=0; r<ncol; r++) model->setHorizontalHeaderItem( r, new QStandardItem( QString(cols[r] )) );

    for( int r=0; r<nrow; r++ )
    {
        QStandardItem *item_name = new QStandardItem(QString(names[r]));
        QStandardItem *item_sname = new QStandardItem(QString(snames[r]));
        QStandardItem *item_ages = new QStandardItem(QString(ages[r]));
        QStandardItem *item_address = new QStandardItem(QString(addresses[r]));
        model->setItem(r, 0, item_name);
        model->setItem(r, 1, item_sname);
        model->setItem(r, 2, item_ages);
        model->setItem(r, 3, item_address);
    }
    table->setModel(model);

    table->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
    // table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
}

void Evidence::showInfo(string name, string sname, string age, string address)
{
    selectedAddress = address;

    QWidget *window = new QWidget();
    window->setWindowTitle("Info");

    QVBoxLayout *windowLayout = new QVBoxLayout();
    windowLayout->setMargin(15);
    windowLayout->setSpacing(15);

    // Vlozeni obrazku (photo je QLabel*):
    // photo->setPixmap(QPixmap(tr("path/to/linux-penguin.jpg")));

    // Vlozeni jmena, prijmeni, veku, adresy

    char url[200];
    sprintf(url, mapUrl, address.c_str(), "15");

    // Vlozeni mapy

    // Vlozeni zoomu

    window->setLayout(windowLayout);
    window->show();
}

string Evidence::intToString(int n)
{
    stringstream ss;
    ss << n;
    return ss.str();
}

void Evidence::personSelected(const QModelIndex& index)
{
    int r = index.row();

    string name = model->item(r, 0)->text().toStdString();
    string sname = model->item(r, 1)->text().toStdString();
    string age = model->item(r, 2)->text().toStdString();
    string address = model->item(r, 3)->text().toStdString();

    showInfo(name, sname, age, address);
}

void Evidence::zoomChanged(int zoom)
{
    string zoomVal = intToString(zoom);
    // Zmente zoomLabel text

    char url[200];
    sprintf(url, mapUrl, selectedAddress.c_str(), zoomVal.c_str());
    // Zmente map url
}

Evidence::~Evidence()
{
    if (mapUrl != NULL) {
        delete mapUrl;
        mapUrl = NULL;
    }
}
